@@ -184,7 +184,6 @@ void TarArch::updateProgress( TDEProcess * _proc, char *_buffer, int _bufflen )
       _proc->kill();
       KMessageBox::error(0, i18n("Trouble writing to the archive..."));
       kdWarning( 1601 ) << "trouble updating tar archive" << endl;
-      //kdFatal( 1601 ) << "trouble updating tar archive" << endl;
     }
 }
 
@@ -198,16 +197,19 @@ TQString TarArch::getCompressor()
     if ( m_fileMimeType == "application/x-tgz" )
         return TQString( "gzip" );
 
-    if (  m_fileMimeType == "application/x-tbz" )
+    if ( m_fileMimeType == "application/x-tbz" )
         return TQString( "bzip2" );
 
-   if (  m_fileMimeType == "application/x-tlz" )
-       return TQString( "lzma" );
+    if ( m_fileMimeType == "application/x-tlzma" )
+        return TQString( "lzma" );
 
-   if (  m_fileMimeType == "application/x-txz" )
-       return TQString( "xz" );
+    if ( m_fileMimeType == "application/x-tlz" )
+        return TQString( "lzip" );
 
-    if( m_fileMimeType == "application/x-tzo" )
+    if ( m_fileMimeType == "application/x-txz" )
+        return TQString( "xz" );
+
+    if ( m_fileMimeType == "application/x-tzo" )
         return TQString( "lzop" );
 
     return TQString();
@@ -222,23 +224,25 @@ TQString TarArch::getUnCompressor()
     if ( m_fileMimeType == "application/x-tgz" )
         return TQString( "gunzip" );
 
-    if (  m_fileMimeType == "application/x-tbz" )
+    if ( m_fileMimeType == "application/x-tbz" )
         return TQString( "bunzip2" );
 
-   if (  m_fileMimeType == "application/x-tlz" )
-       return TQString( "unlzma" );
+    if ( m_fileMimeType == "application/x-tlzma" )
+        return TQString( "lzma" );
 
-   if (  m_fileMimeType == "application/x-txz" )
+    if ( m_fileMimeType == "application/x-tlz" )
+        return TQString( "lzip" );
+
+    if ( m_fileMimeType == "application/x-txz" )
        return TQString( "unxz" );
 
-    if( m_fileMimeType == "application/x-tzo" )
+    if ( m_fileMimeType == "application/x-tzo" )
         return TQString( "lzop" );
 
     return TQString();
 }
 
-void
-TarArch::open()
+void TarArch::open()
 {
     if ( compressed )
         TQFile::remove(tmpfile); // just to make sure
@@ -391,7 +395,10 @@ void TarArch::createTmp()
             kdDebug(1601) << "Uncompressor is " << strUncompressor << endl;
             *kp << strUncompressor;
             TDEProcess::Communication flag = TDEProcess::AllOutput;
-            if (strUncompressor == "lzop")
+            if (strUncompressor == "lzip" || strUncompressor == "lzma") {
+                *kp << "-d";
+            }
+            else if (strUncompressor == "lzop")
             {
                 // setting up a pty for lzop, since it doesn't like stdin to
                 // be /dev/null ( "no filename allowed when reading from stdin" )
@@ -789,12 +796,10 @@ void TarArch::test()
 
   *kp << uncomp;
 
-  if( uncomp == "bunzip2" || uncomp == "gunzip" || uncomp == "lzop" )
-  {
+  if ((uncomp == "bunzip2") || (uncomp == "gunzip") || (uncomp == "lzip") || (uncomp == "lzop")) {
     *kp << "-t";
   }
-  else
-  {
+  else {
     Arch::test();
     return;
   }
