@@ -35,15 +35,6 @@
 
 namespace KMilo {
 
-// now the key data (from kkeyserver_x11.h and $TQTDIR/include/tqnamespace.h)
-struct ShortcutInfo
-{
-	const char* name;
-	uint symbol;
-	const char *slot;
-};
-
-
 class GenericMonitor : public Monitor
 {
 	Q_OBJECT
@@ -63,7 +54,7 @@ public slots:
   void slowVolumeDown();
   void fastVolumeUp();
   void fastVolumeDown();
-  void mute();
+  void toggleMute();
   void brightnessUp();
   void brightnessDown();
   void brightnessSlowUp();
@@ -81,11 +72,9 @@ public slots:
   void pmBattery();
 
 private:
-	bool retrieveKmixDevices();
-	void volumeChange(int direction, int step);
-	bool retrieveMute();
-	bool retrieveVolume();
-	void displayVolume();
+	void volumeChange(int direction, int percentage);
+	bool retrieveMute(bool &muted);
+	bool retrieveVolume(int &volume);
 	void brightnessChange(int direction, int step);
 	void launch(TQString configKey, TQString defaultApplication);
 
@@ -95,14 +84,9 @@ private:
 	DCOPRef *kmixClient, *kmixWindow, *tdepowersave;
 
 	int m_progress;
-	long m_volume;
-	bool m_mute;
-
-	long m_maxVolume, m_minVolume;
 
 	// following properties are read from config file:
 	int m_volumeStepFast, m_volumeStepSlow;
-	int m_volumeDeviceIdx, m_muteDeviceIdx, m_extraDeviceIdx;
 	bool m_enabled;
 
 	Monitor::DisplayType m_displayType;
