@@ -310,7 +310,7 @@ karamba::karamba(TQString fn, TQString name, bool reloading, int instance,
     move(xpos, ypos);
   }
 
-  haveUpdated = 0;
+  haveUpdated = false;
   this->setMouseTracking(true);
 
 
@@ -1691,14 +1691,13 @@ void karamba::step()
 
   if (pythonIface && pythonIface->isExtensionLoaded())
   {
-    if (haveUpdated == 0)
+    if (!haveUpdated)
       pythonIface->initWidget(this);
     else
       pythonIface->widgetUpdated(this);
   }
 
-  if (haveUpdated == 0)
-    haveUpdated = 1;
+  haveUpdated = true;
 }
 
 void karamba::widgetClosed()
